****************************************************************************************************************
****************************************************************************************************************
***Author: Sergi Vidal [svidal@ced.uab.es]; Philipp M. Lersch  
***Project: Vidal, Sergi and Philipp M. Lersch. 2019. “Changes in gender role attitudes following couples' residential relocations.” Demographic Research 40:1111–1152.
***Data set: British Household Panel Survey Waves 1-18 (UK Data Archive Study Number 5151); British Household Panel Survey, Waves 1-18, 1991-2009: Conditional Access, Local Authority Districts (UK Data Archive Study Number 6027)  
****************************************************************************************************************
****************************************************************************************************************

******************************************************
**S E C O N D A R Y (primary: MASTER.do)**
******************************************************


****************************************************************************************************************
****************************************************************************************************************
********Descriptive analysis
****************************************************************************************************************
****************************************************************************************************************

use "$output/prepared",clear

keep if sample==1

****************************************************************************************************************
***case numbers (To build Table 1)

distinct pid if woman==1
distinct pid if woman==0
distinct pid if woman==1 & move_before==1
distinct pid if woman==0 & move_before==1
foreach coef in 1.moveshort 1.movelong 1.movework 1.movefam 1.movedwel 1.moveother 1.moveforbothjob 1.moveforhisjob 1.moveforherjob 1.movefornonejob {
	distinct pid if woman==1 & `coef'_before==1
	distinct pid if woman==0 & `coef'_before==1
	}

 
****************************************************************************************************************
***mean of gender ideology by gender

sum z_ideologya if woman==1 [weight=weight]
sum z_ideologya if woman==0 [weight=weight]

****************************************************************************************************************
***distribution gender ideology by gender and relocation (before/after) (Figure 1)

forvalues w=0/1{
	reg z_ideologya age if woman==`w'
	predict resid`w'
	reg resid`w' move_before if woman==`w' [weight=weight], vce(cluster pid)
	local test_residualised_`w'=round((2 * ttail(e(df_r), abs(_b[move_before]/_se[move_before]))),0.001)
	reg z_ideologya move_before if woman==`w' [weight=weight], vce(cluster pid)
	local test_raw_`w'=round((2 * ttail(e(df_r), abs(_b[move_before]/_se[move_before]))),0.001)	
	forvalues m=0/1{
		sum resid`w' if woman==`w' & move_before==`m' [weight=weight]
		local m_residualised_`w'_`m'=r(mean)
		sum z_ideologya if woman==`w' & move_before==`m' [weight=weight]
		local m_raw_`w'_`m'=r(mean)		
		}
	}
		
*residualised on age		
twoway (kdensity resid1 if woman==1 & move_before==1 [weight=weight],bw(.4) lcolor(red) lpattern(solid)) ///
	(kdensity resid1 if woman==1 & move_before==0 [weight=weight],bw(.4) lcolor(black) lpattern(dash)) ,	///
	legend(order(1 2) label(1 "Relocation") label(2 "No Relocation") position(6) col(1) region(style(none))) title(Women) ///
	xtitle("GRA - egalitarian gender ideology") ytitle(Density) ylabel(,angle(0)) ///
	xline(`m_residualised_1_1',lcolor(red)) xline(`m_residualised_1_0',lcolor(black) lpattern(dash)) text(.1 0.5 "p<.01") ///
	name(kdensity_residualised_women,replace) xscale(range(-1 1)) xlabel(-1(.5)1) ylabel(0 (.2) .8) scale(1.5)

twoway (kdensity resid0 if woman==0 & move_before==1 [weight=weight],bw(.4) lcolor(red) lpattern(solid)) ///
	(kdensity resid0 if woman==0 & move_before==0 [weight=weight],bw(.4) lcolor(black) lpattern(dash)) ,	///
	legend(order(1 2) label(1 "Relocation") label(2 "No Relocation") position(6) col(1) region(style(none))) title(Men) ///
	xtitle("GRA - egalitarian gender ideology") ytitle(Density) ylabel(,angle(0)) ///
	xline(`m_residualised_0_1',lcolor(red)) xline(`m_residualised_0_0',lcolor(black) lpattern(dash)) text(.1 0.5 "p<.01") ///
	name(kdensity_residualised_men,replace) xscale(range(-1 1)) xlabel(-1(.5)1) ylabel(0 (.2) .8)  scale(1.5)

graph combine kdensity_residualised_women kdensity_residualised_men,name(combined_residualised,replace) saving("$graph/density_residualised_combined",replace)	

graph export "$graph/density_residualised_combined.png",width(1000) replace	


****************************************************************************************************************
***mean gender ideology by relocation type (before/after) (Figure 2)

local title1 "Women"
local title0 "Men"

forvalues w=0/1{
	capture drop coef ub lb n
	gen coef=.
	gen ub=.
	gen lb=.
	gen n=_n in 1/12

	local n=1
	foreach coef in 0.move 1.move 1.moveshort 1.movelong 1.movework 1.movefam 1.movedwel 1.moveother 1.moveforbothjob 1.moveforhisjob 1.moveforherjob 1.movefornonejob {
		capture drop resid
		reg z_ideologya age if woman==`w' 
		predict resid
		reg resid `coef'_before if woman==`w' [weight=weight],noconstant vce(cluster pid)
		replace coef=_b[`coef'_before] if n==`n'
		replace ub=_b[`coef'_before]+1.96*_se[`coef'_before] if n==`n'	
		replace lb=_b[`coef'_before]-1.96*_se[`coef'_before] if n==`n'		
		local n=`n'+1
		}

	graph twoway (bar coef n if n<13, barwidth(0.8)) ///
		(rcap ub lb n  if n<13, msize(huge)), legend(off) scale(1.3) yscale(range(-.2 .6)) ylabel(-.2 (.2) .6) ///
		ytitle("Average gender role attitudes") xtitle(" ") title("`title`w''") ///
		xlabel(1 "No/before relocation" 2 "Any relocation" 3 "Short (<50km)" 4 "Long (>=50km)" 5 "for job" 6 "for family" 7 "for dwelling" 8 "for other reasons" 9 "for both jobs" 10 "for his job" 11 "for her job" 12 "for none jobs" ,angle(35)) ///
		name(meangra`w',replace) saving("$graph/meangra`w'",replace)
		graph export "$graph/meangra`w'.eps", replace	
		graph export "$graph/meangra`w'.png", replace	width(1000)	
		
list coef ub lb n if n<13

	}

window manage close graph _all


*************************************
*Summary statistics (to build Table A1)

preserve
clonevar  wave=svyyear 
gen educ1=(casmin==1)
gen educ2=(casmin==2)
gen educ3=(casmin==3)
tab age_cat2, ge(ages)
tab children, gen(ch)

forvalues s=0/1{
	local rowname=""
	matrix D`s'=J(1,2,.)

	foreach var in move_repeated timesincelastmove ages1 ages2 ages3 ages4 svyyear married ch1 ch2 ch3 ///
	hhinclog empl fulltime p_empl p_fulltime educ1 educ2 educ3 housework2 homeowner hsroom urban {
		forvalues i=0/1{
				qui:sum `var' if woman==`s', d
				matrix X=(round(r(mean),0.001), round(r(sd),0.001))      
			}
		local rowname "`rowname' `var'"
		matrix D`s'=(D`s'\X)
		}       
	 
	matrix D`s'=D`s'[2...,1...]
	matrix rownames D`s' = `rowname'
	}
local rowname=""
matrix D2=J(1,4,.)
	foreach var in move_repeated timesincelastmove ages1 ages2 ages3 ages4 svyyear married ch1 ch2 ch3 ///
	hhinclog empl fulltime p_empl p_fulltime educ1 educ2 educ3 housework2 homeowner hsroom urban {
		forvalues i=0/1{
				qui:sum `var', d
				matrix X=(round(r(mean),0.001), round(r(sd),0.001),round(r(min),0.001), round(r(max),0.001))      
			}
	local rowname "`rowname' `var'"
	matrix D2=(D2\X)
		}       
	 
	matrix D2=D2[2...,1...]
	matrix rownames D2 = `rowname'
	
matrix D =(D0,D1,D2)
matrix colnames D = M_0 SD_0 M_1 SD_1 M_2 SD_2 MIN_2 MAX_2 

mat2txt, matrix(D) saving("$output/univariate Table 1 paper.csv") format(%9.3f) replace
restore

window manage close graph _all

**last line
