****************************************************************************************************************
****************************************************************************************************************
***Author: Sergi Vidal [svidal@ced.uab.es]; Philipp M. Lersch 
***Project: Vidal, Sergi and Philipp M. Lersch. 2019. “Changes in gender role attitudes following couples' residential relocations.” Demographic Research 40:1111–1152.
***Data set: British Household Panel Survey Waves 1-18 (UK Data Archive Study Number 5151); British Household Panel Survey, Waves 1-18, 1991-2009: Conditional Access, Local Authority Districts (UK Data Archive Study Number 6027)  
****************************************************************************************************************
****************************************************************************************************************

******************************************************
**S E C O N D A R Y (primary: MASTER.do)**
******************************************************


****************************************************************************************************************
****************************************************************************************************************
********generate variables
****************************************************************************************************************
****************************************************************************************************************

use "$output/retrieval",clear

***general labels
lab def yesno 0 "No" 1 "Yes", replace

****************************************************************************************************************
***weights for all samples

gen weight=xrwght if svyyear<1999
replace weight=xrwtsw1 if svyyear==1999 | svyyear==2000 
replace weight=xrwtuk1 if svyyear>2000

replace weight=. if memorig==2 | memorig==3 | memorig==4 | memorig==7	/*weight missing for ECHP and Northern Ireland sample*/

lab var weight "Weight" 

****************************************************************************************************************
***age

replace doby=. if doby==9898

replace age=svyyear-doby if age==. & doby<. & svyyear-doby>=0

lab var age "Age"

recode age (0/34=0) (35/49=1) (50/150=2), ge(age_cat)  
recode age (0/29=0) (30/39=1) (40/49=2) (50/150=3), ge(age_cat2)  

replace age=age-16
gen age2=age*age

****************************************************************************************************************
***cohorts

recode doby (min/1930=1) (1931/1945=2) (1946/1960=3) (1961/1975=4) (1976/max=5), gen(cohort)

lab var cohort "Cohort"
lab def cohort 1 "-1930" 2 "1931-1945" 3 "1946-1960" 4 "1961-1975" 5 "1976-"
lab val cohort cohort

****************************************************************************************************************
***women and men

gen woman=0+(sex==2) if ~missing(sex)
gen man=0+(sex==1) if ~missing(sex)

lab var woman "Woman?"
lab var man "Man?"
lab val woman man yesno

****************************************************************************************************************
***partner identification number

gen double partpid=sppid
format partpid %20.0f
mvdecode partpid, mv(0=.a)

lab var partpid "PID of Partner"

****************************************************************************************************************
***construct gender ideology measure

***reverse traditional attitudes and transform to range -2 to 2
foreach var in opfamc opfamd opfame opfamg opfamh opfami{
	local l`var' : variable label `var'
	gen `var'2=`var'*-1+6
	replace `var'2=`var'2-3
	lab var `var'2 "`l`var''"
	} 

foreach var in opfama opfamb opfamf{
	local l`var' : variable label `var'
	gen `var'2=`var'-3
	lab var `var'2 "`l`var''"	
	}
	
lab def opfa -2 "strongly traditional" -1 "traditional" 0 "neutral" 1 "egalitarian" 2 "strongly egalitarian"
lab val opfa*2 opfa	

***generate average ideology measure
egen ideologyb=rowmean(opfama2 opfamb2 opfamf2 opfamc2 opfamd2 opfame2 opfamg2)
egen missingb=rowmiss(opfama2 opfamb2 opfamf2 opfamc2 opfamd2 opfame2 opfamg2)
replace ideologyb=. if missingb>3
egen ideologya=rowmean(opfama2 opfamb2 opfamf2) if ~missing(opfama2,opfamb2,opfamf2)
egen ideologyc=rowmean(opfamc2 opfamd2 opfame2 opfamg2) if ~missing(opfamc2,opfamd2,opfame2,opfamg2)

lab var ideologya "Egalitarian gender ideology (better alpha)"
lab var ideologyb "Egalitarian gender ideology (all items)"
lab var ideologyc "Egalitarian gender ideology (dropped items)"

summ ideologya
gen sd_ideologya=r(sd)
gen m_ideologya=r(mean)

gen z_ideologya = (ideologya-m_ideologya)/sd_ideologya
lab var z_ideologya "Egalitarian gender ideology (better alpha, Z-standarized)"

****************************************************************************************************************
**residental move

gen movelong=1 if distmov>=50 & ~missing(distmov)
replace movelong=0 if distmov<50 | distmov==.b 
replace movelong=0 if movelong==. & hhmove==1

gen moveshort=1 if distmov<50
replace moveshort=0 if (distmov>49 & ~missing(distmov)) | distmov==.b
replace moveshort=0 if moveshort==. & hhmove==1

gen move=1 if ~missing(distmov)
replace move=0 if distmov==.b
replace move=0 if move==. & hhmove==1
replace move=1 if move==. & hhmove==2

lab var movelong "Long-distance move"
lab var moveshort "Short-distance move"
lab var move "Short- and long-distance move"
lab val movelong moveshort move yesno

****************************************************************************************************************
***reason of move

recode movy1 movy2 (1/6=1) (10/14=2) (15/49=3) (96=4), pre(new)

gen movework=0+(movjb==1 | newmovy1==2 | newmovy2==2) if ~missing(movjb) | movjb==.b | ~missing(newmovy1) | ~missing(newmovy2)
gen movefam=0+(newmovy1==1 | newmovy2==1) if ~missing(newmovy1) | ~missing(newmovy2) | newmovy1==.b | newmovy2==.b 
gen movedwel=0+(newmovy1==3 | newmovy2==3) if ~missing(newmovy1) | ~missing(newmovy2) | newmovy1==.b | newmovy2==.b  
gen moveother=0+(newmovy1==4 | newmovy2==4) if ~missing(newmovy1) | ~missing(newmovy2) | newmovy1==.b  | newmovy2==.b 

*combined job reasons

bysort hid svyyear (hgr2r): gen count=_n if hgr2r<4
sort hid svyyear hgr2r
egen maxcount=max(count) if hgr2r<4, by(hid svyyear)
gen moveforhis=1 if movework==1 & man==1 & hgr2r<4
gen moveforher=1 if movework==1 & woman==1 & hgr2r<4
egen maxmoveforhis=max(moveforhis) if hgr2r<4, by(hid svyyear)
egen maxmoveforher=max(moveforher) if hgr2r<4, by(hid svyyear)
gen moveforany=1 if movework==1 & hgr2r<4
egen moveforwho=count(moveforany), by(hid svyyear)
gen moveforbothjob=(moveforwho==2 & maxcount==2)
gen moveforhisjob=(moveforwho==1 & maxmoveforhis==1 & maxcount==2)
gen moveforherjob=(moveforwho==1 & maxmoveforher==1 & maxcount==2)
gen movefornonejob=(moveforwho==0 & maxcount==2 & (movefam==1 | movedwel==1 | moveother==1))

sort pid svyyear

foreach var in movework movefam movedwel moveother moveforbothjob moveforhisjob moveforherjob movefornonejob{
	replace `var'=0 if move==0			/*TODO movest (individual mover status) does not correspond to plnew (not resident one year ago), that is why I give priority to movest (via distmov) here*/
	lab val `var' yesno 
	}
	
lab var movework "Moved for work"
lab var movefam "Moved for family/friends"
lab var movedwel "Moved for dwelling"
lab var moveother "Moved for other reasons"	 
	
****************************************************************************************************************
***timing

xtset pid svyyear

foreach var in movelong moveshort move movework movefam movedwel moveother moveforbothjob moveforhisjob moveforherjob movefornonejob{
	gen `var'_time=0 if ~missing(`var')
	replace `var'_time=5 if (l7.`var'==1 | l8.`var'==1 | l9.`var'==1 | l10.`var'==1 | l11.`var'==1 | l12.`var'==1 | l13.`var'==1 | l14.`var'==1 | l15.`var'==1 | l16.`var'==1 | l17.`var'==1) /*give priority to most recent move if several moves observed*/
	replace `var'_time=4 if (l5.`var'==1 | l6.`var'==1)
	replace `var'_time=3 if (l3.`var'==1 | l4.`var'==1)
	replace `var'_time=2 if (l1.`var'==1 | l2.`var'==1)
	replace `var'_time=1 if (f1.`var'==1) | (f2.`var'==1)
	}
	
lab def timing 0 "t-3 and earlier and no move" 1 "t-2/t-1" 2 "t+1/t+2" 3 "t+3/t+4" 4 "t+5/t+6" 5 "t+7 and later"
lab val *_time timing

lab var movework_time "Timing of moved for work"
lab var movefam_time "Timing of moved for family/friends"
lab var movedwel_time "Timing of moved for dwelling"
lab var moveother_time "Timing of moved for other reasons"	   	
lab var movelong_time "Timing of long-distance move"
lab var moveshort_time "Timing of short-distance move"
lab var move_time "Timing of short- and long-distance move"

foreach var in movelong moveshort move movework movefam movedwel moveother moveforbothjob moveforhisjob moveforherjob movefornonejob{
	gen `var'_timep=0 if ~missing(`var')
	replace `var'_timep=12 if (l11.`var'==1 | l12.`var'==1 | l13.`var'==1 | l14.`var'==1 | l15.`var'==1 | l16.`var'==1 | l17.`var'==1) /*give priority to most recent move if several moves observed*/
	replace `var'_timep=11 if l10.`var'==1		
	replace `var'_timep=10 if l9.`var'==1 
	replace `var'_timep=9 if l8.`var'==1 	
	replace `var'_timep=8 if l7.`var'==1 
	replace `var'_timep=7 if l6.`var'==1 
	replace `var'_timep=6 if l5.`var'==1 	
	replace `var'_timep=5 if l4.`var'==1 	
	replace `var'_timep=4 if l3.`var'==1 
	replace `var'_timep=3 if l2.`var'==1 	
	replace `var'_timep=2 if l1.`var'==1 
	replace `var'_timep=1 if `var'==1 
	}

gen timesincelastmove=move_timep
recode timesincelastmove (1=0) (2/12=1) 
bysort pid (svyyear): replace timesincelastmove=0 if _n==1
lab var timesincelastmove "More than two years since last move?"
lab val timesincelastmove yesno

****************************************************************************************************************
***mobility before after dummy

sort pid svyyear
foreach var in movelong moveshort move movework movefam movedwel moveother moveforbothjob moveforhisjob moveforherjob movefornonejob{
	by pid (svyyear): gen `var'_before=0 if _n==1
	replace `var'_before=0 if ~missing(`var') 
	by pid (svyyear): replace `var'_before=0 if missing(`var') & ~missing(`var'[_n-1]) & ~missing(`var'[_n+1])  /*TODO one year gap is replace here without further check*/	
	replace `var'_before=1 if `var'==1
	by pid (svyyear): replace `var'_before=`var'_before+`var'_before[_n-1] if _n>1 & `var'_before[_n-1]!=.
	gen `var'_repeated=0+(`var'_before>1) if ~missing(`var'_before)
	recode `var'_before (1/max=1)
	}
	
****************************************************************************************************************
***married partner in hh?

gen partnerhh=.
replace partnerhh=0 if spinhh==2
replace partnerhh=1 if spinhh==1 & mastat>1 & mastat<11
replace partnerhh=2 if spinhh==1 & mastat==1

lab def partnerhh 0 "no partner" 1 "steady partner in hh" 2 "spouse in hh"
lab val partnerhh partnerhh
lab var partnerhh "Married or steady partner lives in hh"

gen married=0+(partnerhh==2) if ~missing(partnerhh)
lab var married "Married?"
lab val married yesno

gen couple=0+(partnerhh>0 & partnerhh<3) if ~missing(partnerhh)
lab var couple "Couple?"
lab val couple yesno

**************************************************************************************************************
***employment status

recode jbstat (1 2=1) (3=2) (4=3) (5=4) (6=5) (7 9=6) (8=7) (10=8),gen(lfs2)
lab def lfs2  1 "employed" 2 "unemployed" 3 "retired" 4 "mat leave" 5 "housewife" 6 "education" 7 "disabled" 8 "other"
lab val lfs2 lfs2
lab var lfs2 "Labour force status (compiled)" 
replace lfs2=-1 if missing(jbstat)

* empl
recode lfs2 (1=1) (2/8=0) (else=.),gen(empl)
lab var empl "(Self-) employed?"
lab val empl yesno

****************************************************************************************************************
***work hours

tempvar sechours
recode j2hrs (99/max=99), gen(`sechours')

gen jobhours=jbhrs if jbstat==2
replace jobhours=jshrs if jbstat==1
replace jobhours=0 if empl~=1

lab var jobhours "Work hours"

recode jobhours (0/34=0) (35/1000=1), gen(fulltime)

****************************************************************************************************************
***employment status partner

gen p_empl=0+(spjb==1) if ~missing(spjb)

lab var p_empl "Partner employed?"
lab val p_empl yesno

****************************************************************************************************************
***work hours partner

tempvar sechours
recode spjbhr (99/max=99), gen(`sechours')

gen p_jobhours=spjbhr if p_empl==1
replace p_jobhours=0 if p_empl==0

lab var p_jobhours "Partner's work hours"

recode p_jobhours (0/34=0) (35/1000=1), gen(p_fulltime)

****************************************************************************************************************
***housework hours

clonevar househours=howlng

recode househours (0/6=0) (7/15=1) (16/99=2), gen(housework1)

recode househours (0/9=0) (10/99=1), gen(housework2)

****************************************************************************************************************
***caring hours

recode aidhrs (4/7=1) (9=1) (1/3=0) (8=0) (10=0), ge(carehours)

lab var carehours "More than 20 hours of care work a week"
lab val carehours yesno

****************************************************************************************************************
**count agegroups in household

sort hid svyyear 

egen age0t13=sum(age<14), by(hid svyyear)
egen age14plus=sum(age>13 & age<.), by(hid svyyear)

****************************************************************************************************************
***age of children

egen child0t4=sum(age<5 & hgr2r>3 & hgr2r<9), by(hid svyyear)
egen child5t17=sum(age>4 & age<18 & hgr2r>3 & hgr2r<9), by(hid svyyear)

gen children=0 if child0t4==0 & child5t17==0
replace children=1 if child0t4>0 & ~missing(child0t4)
replace children=2 if child0t4==0 & child5t17>0 & ~missing(child5t17)
 
gen morechildren=0+(child0t4+child5t17>1) if ~missing(child0t4) & ~missing(child5t17)

lab var child0t4 "AL 1 hh member aged 0 to 4"
lab var child5t17 "AL 1 hh member aged 5 to 17"
lab var children "Age of child(ren)"
lab def children 0 "No children" 1 "Children aged -4" 2 "Children aged 5-17"
lab val children children
lab var morechildren "More than one child"
lab val morechildren yesno

****************************************************************************************************************
***homeownership

recode tenure (1 2=1) (else=0), gen(homeowner)

lab var homeowner "Homeowner"
lab val homeowner yesno

**************************************************************************************************************
***income of hh 

**Consumer Price Index (again for cases with missing housing price information)

gen cpi=75.07 if svyyear==1991 
replace cpi=78.30 if svyyear==1992 
replace cpi=80.25 if svyyear==1993 
replace cpi=81.92 if svyyear==1994 
replace cpi=84.07 if svyyear==1995 
replace cpi=86.12 if svyyear==1996 
replace cpi=87.68 if svyyear==1997 
replace cpi=89.05 if svyyear==1998 
replace cpi=90.22 if svyyear==1999 
replace cpi=91.01 if svyyear==2000 
replace cpi=92.08 if svyyear==2001 
replace cpi=93.26 if svyyear==2002 
replace cpi=94.53 if svyyear==2003 
replace cpi=95.80 if svyyear==2004 
replace cpi=97.75 if svyyear==2005 
replace cpi=100.00 if svyyear==2006 
replace cpi=102.35 if svyyear==2007 
replace cpi=106.06 if svyyear==2008 
replace cpi=108.31 if svyyear==2009 

gen hhinc=((fihhyr)*(100/cpi))/((age0t13*0.3)+(age14plus*0.5)+0.5)
gen hhinclog=log(hhinc+1)

lab var hhinc "Income of hh (modified OECD-scale, prices of 2006)"
lab var hhinclog "Log income of hh (modified OECD-scale, prices of 2006)" 

****************************************************************************************************************
***education

recode casmin (0=.) (1 2 3=1) (4 5 6 7=2) (8 9=3), gen(casmin2)

lab var casmin2 "CASMIN Classification (simplified)"
lab def casmin2 1 "Basic (1a 1b 1c)" 2 "Intermediate (2a 2b 2c_gen 2c_voc)" 3 "Higher (3a 3b)"
lab val casmin2 casmin2 

****************************************************************************************************************
***maternal employment when respondent was 14 y.o.

gen moth_emp_14=.
replace moth_emp_14=0 if maju!=. & maju!=.b & maju!=.a
replace moth_emp_14=1 if masoc!=. & masoc!=.b  & masoc!=.a 

bysort pid (svyyear): egen xxx= mean(moth_emp_14)
replace xxx=1 if xxx==.5

replace moth_emp_14=xxx
drop xxx
lab var moth_emp_14 "Maternal employment in childhood"
lab val moth_emp_14 yesno

****************************************************************************************************************
***moves to
*urban
bysort pid (svyyear): gen xxx= (urban==1 & urban[_n-1]==0 & move_before==1) 
bysort pid (svyyear): gen yyy= (urban==0 & urban[_n-1]==1 & move_before==1)
recode xxx yyy (.=0)
bysort pid (svyyear): egen tourban=max(xxx)
bysort pid (svyyear): egen torural=max(yyy)
drop xxx yyy 
*homeownership
bysort pid (svyyear): gen xxx= (homeowner==1 & homeowner[_n-1]==0 & move_before==1)
bysort pid (svyyear): gen yyy= (homeowner==0 & homeowner[_n-1]==1 & move_before==1)
recode xxx yyy (.=0)
bysort pid (svyyear): egen tohomeowner=max(xxx)
bysort pid (svyyear): egen torent=max(yyy)
drop xxx yyy 
*fulltime
bysort pid (svyyear): gen xxx= (fulltime==1 & fulltime[_n-1]==0 & move_before==1)
bysort pid (svyyear): gen yyy= (fulltime==0 & fulltime[_n-1]==1 & move_before==1)
recode xxx yyy (.=0)
bysort pid (svyyear): egen tofulltime=max(xxx)
bysort pid (svyyear): egen toparttime=max(yyy)
drop xxx yyy 
*number of rooms
bysort pid (svyyear): gen xxx= (hsroom>hsroom[_n-1] & move_before==1 & hsroom!=. & hsroom[_n-1]!=.)
bysort pid (svyyear): gen yyy= (hsroom[_n-1]>hsroom & move_before==1 & hsroom!=. & hsroom[_n-1]!=.)
recode xxx yyy (.=0)
bysort pid (svyyear): egen tomorerooms=max(xxx)
bysort pid (svyyear): egen tolessrooms=max(yyy)
drop xxx yyy 
*housework
bysort pid (svyyear): gen xxx= (housework2==1 & housework2[_n-1]==0 & move_before==1)
bysort pid (svyyear): gen yyy= (housework2==0 & housework2[_n-1]==1 & move_before==1)
recode xxx yyy (.=0)
bysort pid (svyyear): egen tohousework=max(xxx)
bysort pid (svyyear): egen tolesswork=max(yyy)
drop xxx yyy 
recode to* (1=0) if move_before==0

****************************************************************************************************************
**clean up	

save "$output/temp_generated",replace
use "$output/temp_generated",clear

keep pid svyyear jobhours househours empl couple age age_cat age_cat2 woman movelong moveshort move *_before *_time *_timep *_repeated hsroom ///
	memorig hgr2r children morechildren married	ideology* partnerhh hhinclog jbstat ivfio homeowner hhtype urban weight ///
	p_empl p_jobhours casmin2 carehours moth_emp_14 z_ideologya timesincelastmove age2 fulltime p_fulltime housework* to*

 

**last line
