****************************************************************************************************************
****************************************************************************************************************
***Author: Sergi Vidal [svidal@ced.uab.es]; Philipp M. Lersch  
***Project: RVidal, Sergi and Philipp M. Lersch. 2019. “Changes in gender role attitudes following couples' residential relocations.” Demographic Research 40:1111–1152.
***Data set: British Household Panel Survey Waves 1-18 (UK Data Archive Study Number 5151); British Household Panel Survey, Waves 1-18, 1991-2009: Conditional Access, Local Authority Districts (UK Data Archive Study Number 6027)  
****************************************************************************************************************
****************************************************************************************************************

******************************************************
**S E C O N D A R Y (primary: MASTER.do)**
******************************************************


****************************************************************************************************************
****************************************************************************************************************
********Multivariate analysis
****************************************************************************************************************
****************************************************************************************************************


use "$output/prepared",clear

keep if sample==1

xtset pid svyyear

****************************************************************************************************************
***before/after comparison (Table 2 / Table A2)

qui: xtreg z_ideologya move_before move_repeated timesincelastmove i.age_cat2 b1993.svyyear married b0.children hhinclog empl jobhours p_empl p_jobhours b1.casmin2 househours homeowner hsroom urban if woman==0,fe vce(cluster pid)
gen analyticalsample= e(sample)
drop if analyticalsample==0 & woman==0
drop analyticalsample
qui: xtreg z_ideologya move_before move_repeated timesincelastmove i.age_cat2 b1993.svyyear married b0.children hhinclog empl jobhours p_empl p_jobhours b1.casmin2 househours homeowner hsroom urban if woman==1,fe vce(cluster pid)
gen analyticalsample= e(sample)
drop if analyticalsample==0 & woman==1
drop analyticalsample

local model1 "move_repeated timesincelastmove i.age_cat2 b1993.svyyear"
local model2 "move_repeated timesincelastmove i.age_cat2 b1993.svyyear married b0.children hhinclog empl fulltime p_empl p_fulltime b1.casmin2 housework2" 
local model3 "move_repeated timesincelastmove i.age_cat2 b1993.svyyear married b0.children  hhinclog empl fulltime p_empl p_fulltime b1.casmin2 housework2 homeowner hsroom urban"
local title1 "Women"
local title0 "Men"

forvalues w=0/1{
		forvalues m=1/3{
				di _c "."
				qui: xtreg z_ideologya move_before `model`m'' if woman==`w',fe vce(cluster pid)
				estimates store est_move_before`m'_w`w'_fe
				qui: xtreg z_ideologya moveshort_before movelong_before `model`m'' if woman==`w',fe vce(cluster pid)
				estimates store est_movedist_before`m'_w`w'_fe
				qui: xtreg z_ideologya movework_before movefam_before movedwel_before moveother_before `model`m'' if woman==`w',fe vce(cluster pid)
				estimates store est_movreas_before`m'_w`w'_fe
				qui: xtreg z_ideologya moveforbothjob_before moveforhisjob_before moveforherjob_before movefornonejob_before `model`m'' if woman==`w',fe vce(cluster pid)
				estimates store est_movcreas_before`m'_w`w'_fe
			}

esttab est_move_before?_w`w'_fe using "$table/move_before_`title`w''.rtf",replace ///
	title("Table X: Linear fixed-effects models of gender ideology (`title`w'')") ///
	cells("b(star fmt(2) label(B))" "se(par fmt(2) label((SE)))") nodep nonumb legend ///
	mgroups("All moves",pattern(1 0 0)) ///
	ml("Model 1" "Model 2" "Model 3") ///
	stats(ll N N_g,label("LL" "N Observations" "N Individuals") fmt(2 0 0)) ///
	drop(*svyyear* 0.*) ///
	 starlevels(* .1 ** .05 *** .01)	varwidth(25) modelwidth(6) ///
	 note("Data: BHPS (1991-2007, unweighted). Note: Outcome variable is egalitarian gender ideology, cluster robust standard errors in parentheses.")	
		
esttab est_movedist_before?_w`w'_fe using "$table/move_distance_before_`title`w''.rtf",replace ///
	title("Table X: Linear fixed-effects models of gender ideology (`title`w'')") ///
	cells("b(star fmt(2) label(B))" "se(par fmt(2) label((SE)))") nodep nonumb legend ///
	mgroups("Short-distance moves" "Long-distance moves",pattern(1 0 0)) ///
	ml("Model 1" "Model 2" "Model 3" ) ///
	stats(ll N N_g,label("LL" "N Observations" "N Individuals") fmt(2 0 0)) ///
	drop(*svyyear* 0.*) ///
	 starlevels(* .1 ** .05 *** .01)	varwidth(25) modelwidth(6) ///
	 note("Data: BHPS (1991-2007, unweighted). Note: Outcome variable is egalitarian gender ideology, cluster robust standard errors in parentheses.")	

esttab est_movreas_before?_w`w'_fe  using "$table/move_reason_before_`title`w''.rtf",replace ///
	title("Table X: Linear fixed-effects models of gender ideology (`title`w'')") ///
	cells("b(star fmt(2) label(B))" "se(par fmt(2) label((SE)))") nodep nonumb legend ///
	mgroups("Moved for job" "Moved for family" "Moved for housing / area" "Moved for other",pattern(1 0 0)) ///
	ml("Model 1" "Model 2" "Model 3") ///
	stats(ll N N_g,label("LL" "N Observations" "N Individuals") fmt(2 0 0)) ///
	drop(*svyyear* 0.*) ///
	 starlevels(* .1 ** .05 *** .01)	varwidth(25) modelwidth(6) ///
	 note("Data: BHPS (1991-2007, unweighted). Note: Outcome variable is egalitarian gender ideology, cluster robust standard errors in parentheses.")		 
	 
esttab est_movcreas_before?_w`w'_fe using "$table/move_creason_before_`title`w''.rtf",replace ///
	title("Table X: Linear fixed-effects models of gender ideology (`title`w'')") ///
	cells("b(star fmt(2) label(B))" "se(par fmt(2) label((SE)))") nodep nonumb legend ///
	ml("Model 1" "Model 2" "Model 3") ///
	stats(ll N N_g,label("LL" "N Observations" "N Individuals") fmt(2 0 0)) ///
	drop(*svyyear* 0.*) ///
	 starlevels(* .1 ** .05 *** .01)	varwidth(25) modelwidth(6) ///
	 note("Data: BHPS (1991-2007, unweighted). Note: Outcome variable is egalitarian gender ideology, cluster robust standard errors in parentheses.")				
	 	}		
	
****************************************************************************************************************
***coefficient plots (Figure 4)

local model1 "move_repeated timesincelastmove i.age_cat2 b1993.svyyear"
local model2 "move_repeated timesincelastmove i.age_cat2 b1993.svyyear married b0.children hhinclog empl fulltime p_empl p_fulltime b1.casmin2 housework2" 
local model3 "move_repeated timesincelastmove i.age_cat2 b1993.svyyear married b0.children  hhinclog empl fulltime p_empl p_fulltime b1.casmin2 housework2 homeowner hsroom urban"
local title1 "Women"
local title0 "Men"
forvalues w=0/1{
	forvalues m=1/3{
				di _c "."
				qui: xtreg z_ideologya move_before `model`m'' if woman==`w',fe vce(cluster pid)
				estimates store est_move_before`m'_w`w'_fe
				qui: xtreg z_ideologya moveshort_before movelong_before `model`m'' if woman==`w',fe vce(cluster pid)
				estimates store est_movedist_before`m'_w`w'_fe
				qui: xtreg z_ideologya movework_before movefam_before movedwel_before moveother_before `model`m'' if woman==`w',fe vce(cluster pid)
				estimates store est_movreas_before`m'_w`w'_fe
				qui: xtreg z_ideologya moveforbothjob_before moveforhisjob_before moveforherjob_before movefornonejob_before `model`m'' if woman==`w',fe vce(cluster pid)
				estimates store est_movcreas_before`m'_w`w'_fe
			}
coefplot(est_movedist_before3_w`w'_fe \ est_movreas_before3_w`w'_fe \ est_movcreas_before3_w`w'_fe ) ///
		, title("`title`w''") ///
						keep(move*_before) coeflab(movelong_before="Observed move >=50km" moveshort_before="Observed move <50km" ///
						movework_before="Observed move for job" movefam_before="Observed move for family" ///
						movedwel_before="Observed move for dwelling" moveother_before="Observed move for others" ///
						moveforhisjob_before="Observed move for his job" moveforbothjob_before="Observed move for the job of both" ///
						moveforherjob_before="Observed move for her job" movefornonejob_before="Observed move for the job of none") ///
						saving("$graph/move_distance_before_`title`w''",replace) name("move_distance_before_`title`w''",replace) ///
						scale(1.3) xtitle("Coefficients") xline(0, lcolor(black)) xscale(range(-0.25 0.35)) xlabel(-0.25(0.05)0.35) 	
}
coefplot(est_movedist_before1_w0_fe \ est_movreas_before1_w0_fe \ est_movcreas_before1_w0_fe ) ///
(est_movedist_before1_w1_fe \ est_movreas_before1_w1_fe \ est_movcreas_before1_w1_fe ) ///
		, 				keep(move*_before) coeflab(movelong_before="                >=50km" moveshort_before="<50km" ///
						movework_before="for job" movefam_before="for family" ///
						movedwel_before="for dwelling" moveother_before="for others" ///
						moveforhisjob_before="for his job" moveforbothjob_before="for the job of both" ///
						moveforherjob_before="for her job" movefornonejob_before="                              for the job of none") ///
						legend(order(- 2 4) label(2 "Men") label(4 "Women")) ///
						saving("$graph/move_distance_before_`title`w''",replace) name("move_distance_before_2",replace) ///
						scale(1.3) xtitle("Coefficients") xline(0, lcolor(black)) xscale(range(-0.3 0.3)) xlabel(-0.3(0.1)0.3) 	levels(95) 	   
	   
	
****************************************************************************************************************
***changes in independent variable related to mobility (Figure 3)

local title1 "Women"
local title0 "Men"
forvalues w=0/1{
				di _c "."
				qui: xtreg z_ideologya tourban torural move_repeated timesincelastmove i.age_cat2 b1993.svyyear  if woman==`w',fe vce(cluster pid)
				estimates store est_move_1before_w`w'_fe
				qui: xtreg z_ideologya  tohomeowner torent  move_repeated timesincelastmove i.age_cat2 b1993.svyyear if woman==`w',fe vce(cluster pid)
				estimates store est_move_2before_w`w'_fe
				qui: xtreg z_ideologya  tofulltime toparttime  move_repeated timesincelastmove i.age_cat2 b1993.svyyear  if woman==`w',fe vce(cluster pid)
				estimates store est_move_4before_w`w'_fe
				qui: xtreg z_ideologya tomorerooms tolessrooms move_repeated timesincelastmove i.age_cat2 b1993.svyyear  if woman==`w',fe vce(cluster pid)
				estimates store est_move_3before_w`w'_fe
				qui: xtreg z_ideologya tohousework tolesswork move_repeated timesincelastmove i.age_cat2 b1993.svyyear  if woman==`w',fe vce(cluster pid)
				estimates store est_move_5before_w`w'_fe
	}
coefplot(est_move_1before_w0_fe \ est_move_2before_w0_fe \ est_move_3before_w0_fe \ est_move_4before_w0_fe \ est_move_5before_w1_fe) ///
(est_move_1before_w1_fe \ est_move_2before_w1_fe \ est_move_3before_w1_fe \ est_move_4before_w1_fe \ est_move_5before_w1_fe) ///
		, 				keep(to*) coeflab(torent="                leave homeownership" tohomeowner="enter homeownership" ///
						tourban="to urban area" torural="to rural area" ///
						tofulltime="enter full-time work" toparttime="leave full-time work" ///
						tohousework="increase housework" tolesswork="decrease housework" ///
						tomorerooms="increase rooms" tolessrooms="decrease rooms" ) ///
						legend(order(- 2 4) label(2 "Men") label(4 "Women")) ///
						saving("$graph/move_distance_before_`title`w''",replace) name("move_distance_before_2",replace) ///
						scale(1.3) xtitle("Coefficients") xline(0, lcolor(black)) xscale(range(-0.3 0.3)) xlabel(-0.3(0.1)0.3) 	levels(95) 	   

**last line	 
				