****************************************************************************************************************
****************************************************************************************************************
***Author: Philipp Lersch [p.m.lersch@uni-koeln.de]; Sergi Vidal
***Project: Vidal, Sergi and Philipp M. Lersch. 2019. “Changes in gender role attitudes following couples' residential relocations.” Demographic Research 40:1111–1152.
***Data set: British Household Panel Survey Waves 1-18 (UK Data Archive Study Number 5151); British Household Panel Survey, Waves 1-18, 1991-2009: Conditional Access, Local Authority Districts (UK Data Archive Study Number 6027)  
****************************************************************************************************************
****************************************************************************************************************

******************************************************
**S E C O N D A R Y (primary: MASTER.do)**
******************************************************


****************************************************************************************************************
****************************************************************************************************************
********retrieve data
****************************************************************************************************************
****************************************************************************************************************


****************************************************************************************************************
***INDALL

***all waves
local ws a b c d e f g h i j k l m n o p q r 
local ys 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008
foreach w of local ws {
	gettoken y ys:ys
	use pid `w'hgr2r ///
	 using "$data/`w'indall",clear
	renpfix `w'
	capture rename id pid
	gen svyyear=`y'
	sort pid
	save "$output/temp_`w'indall", replace
	}

foreach w in a b c d e f g h i j k l m n o p q {
	append using "$output/temp_`w'indall"
	}
sort pid svyyear
save "$output/temp_indall",replace

****************************************************************************************************************
***INDRESP

***all waves
local ws a b c d e f g h i j k l m n o p q r 
local ys 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008
foreach w of local ws {
	gettoken y ys:ys
	use pid `w'fiyrl `w'mastat `w'spinhh `w'jbstat `w'jssat `w'jbterm* `w'cjsbgy4 `w'jbisco `w'isced `w'jbhrs `w'jbot `w'jbotpd ///
	`w'jshrs  `w'jshrs `w'jbopps `w'j2has `w'j2hrs `w'jshrlk `w'jbhrlk `w'jbft `w'jbmngr `w'age `w'sppid `w'hhsize  `w'xrwght ///
	`w'fimnl `w'julk1 `w'julk4 `w'jspl `w'jsttwm `w'jsttwt `w'cjsten `w'fenow `w'scnow `w'jbhad `w'opfam? `w'plnowy4 `w'casmin ///
	`w'spjb `w'spjbhr `w'spjbot `w'aidhrs  ///
	 using "$data/`w'indresp",clear
	renpfix `w'
	capture rename id pid
	gen svyyear=`y'
	sort pid
	save "$output/temp_`w'indresp", replace
	}

foreach w in a b c d e f g h i j k l m n o p q {
	append using "$output/temp_`w'indresp"
	}
sort pid svyyear
save "$output/temp_indrespallwav",replace


***without first wave
local ws b c d e f g h i j k l m n o p q r 
local ys 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008
foreach w of local ws {
	gettoken y ys:ys
	use pid `w'howlng `w'distmov `w'movjb `w'movy1 `w'movy2 `w'plnew `w'movest using "$data/`w'indresp",clear
	renpfix `w'
	capture rename id pid
	gen svyyear=`y'
	sort pid
	save "$output/temp_`w'indresp2", replace
	}

foreach w in b c d e f g h i j k l m n o p q {
	append using "$output/temp_`w'indresp2"
	}
sort pid svyyear
save "$output/temp_indresp2",replace	

***without 1992-1997
local ws a h i j k l m n o p q r 
local ys 1991 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008
foreach w of local ws {
gettoken y ys:ys
	use pid `w'masoc `w'maju using "$data/`w'indresp",clear
	renpfix `w'
	capture rename id pid
	gen svyyear=`y'
	sort pid
	save "$output/temp_`w'indresp3", replace
	}

foreach w in a h i j k l m n o p q {
	append using "$output/temp_`w'indresp3"
	}
sort pid svyyear
save "$output/temp_indresp3",replace	
		
***without 1999
local ws a b c d e f g h  j k l m n o p q r 
local ys 1991 1992 1993 1994 1995 1996 1997 1998 2000 2001 2002 2003 2004 2005 2006 2007 2008
foreach w of local ws {
	gettoken y ys:ys
	use pid `w'hlstat ///
	using "$data/`w'indresp",clear
	renpfix `w'
	capture rename id pid
	gen svyyear=`y'
	sort pid
	save "$output/temp_`w'indresp6", replace
	}
	
foreach w in a b c d e f g h j k l m n o p q {
	append using "$output/temp_`w'indresp6"
	}
sort pid svyyear
save "$output/temp_indresp6",replace

use pid ihlsf1 using "$data/iindresp",clear
renpfix i
gen svyyear=1999
sort pid
save "$output/temp_indresp99", replace

	
***weights from 1999 2000	
local ws i j
local ys 1999 2000 
foreach w of local ws {
	gettoken y ys:ys
	use pid `w'xrwtsw1 ///
	 using "$data/`w'indresp",clear
	renpfix `w'
	gen svyyear=`y'
	sort pid
	save "$output/temp_`w'indresp7", replace
	}

append using "$output/temp_iindresp7"

sort pid svyyear
save "$output/temp_indresp7",replace	

***weights from 2001 onwards	
local ws k l m n o p q r 
local ys 2001 2002 2003 2004 2005 2006 2007 2008
foreach w of local ws {
	gettoken y ys:ys
	use pid `w'xrwtuk1 ///
	 using "$data/`w'indresp",clear
	renpfix `w'
	capture rename id pid
	gen svyyear=`y'
	sort pid
	save "$output/temp_`w'indresp5", replace
	}

foreach w in k l m n o p q {
	append using "$output/temp_`w'indresp5"
	}
sort pid svyyear
save "$output/temp_indresp5",replace	
	
****************************************************************************************************************
***HHRESP

*all waves
local ws a b c d e f g h i j k l m n o p q r 
local ys 1991 1992 1993 1994 1995 1996 1997 1998 1999  2000 2001 2002 2003 2004 2005 2006 2007 2008
foreach w of local ws {
	gettoken y ys:ys
	use `w'hid  `w'tenure `w'hsroom `w'region `w'region2 `w'fihhyr `w'hhtype using "$data/`w'hhresp",clear
	renpfix `w'
	gen svyyear=`y'
	sort hid
	save "$output/temp_`w'hhresp", replace
	}

foreach w in a b c d e f g h i j k l m n o p q {
	append using "$output/temp_`w'hhresp"
	}
sort hid svyyear

save "$output/temp_hhrespallwav",replace

*weights
use ahid  ahhwght   using "$data/ahhresp",clear
rename ahid hid
rename ahhwght xhwght
gen svyyear=1991
save "$output/temp_ahhresp2", replace


local ws b c d e f g h i j k l m n o p q r 
local ys 1992 1993 1994 1995 1996 1997 1998 1999  2000 2001 2002 2003 2004 2005 2006 2007 2008
foreach w of local ws {
	gettoken y ys:ys
	use `w'hid  `w'xhwght `w'hhmove  using "$data/`w'hhresp",clear
	renpfix `w'
	gen svyyear=`y'
	sort hid
	save "$output/temp_`w'hhresp2", replace
	}

foreach w in a b c d e f g h i j k l m n o p q {
	append using "$output/temp_`w'hhresp2"
	}
sort hid svyyear

save "$output/temp_hhresp2",replace

****************************************************************************************************************
***XWAVEID

use pid ?ivfho ?hid ?ivfio using "$data/xwaveid", clear

local ws a b c d e f g h i j k l m n o p q r 
local ys 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008

foreach w of local ws {
	gettoken y ys: ys
	renvars `w'ivfho `w'hid `w'ivfio, postfix(`y')
	renvars `w'ivfho`y' `w'hid`y' `w'ivfio`y', predrop(1)
	}

reshape long ivfho hid ivfio,i(pid) j(svyyear)

lab var hid "Household identification number"
lab var ivfio "Individual interview outcome"
lab var ivfho "Household interview outcome"

sort pid svyyear
save "$output/temp_xwaveid", replace


**************************************************************************************************************** 
****************************************************************************************************************
************* merge temp data files
****************************************************************************************************************
****************************************************************************************************************

use pid sex memorig doby using "$data/xwavedat",clear
expand 18
sort pid
by pid: gen svyyear=1990+_n

merge 1:1 pid svyyear using "$output/temp_xwaveid",nogen keep(1 3)
mvdecode hid,mv(-8)

merge 1:1 pid svyyear using "$output/temp_indall" ,nogen keep(1 3)

merge 1:1 pid svyyear using "$output/temp_indrespallwav" ,nogen keep(1 3)

merge 1:1 pid svyyear using "$output/temp_indresp2" ,nogen keep(1 3)

merge 1:1 pid svyyear using "$output/temp_indresp3" ,nogen keep(1 3)

merge 1:1 pid svyyear using "$output/temp_indresp5" ,nogen keep(1 3)
 
merge 1:1 pid svyyear using "$output/temp_indresp6" ,nogen keep(1 3)

merge 1:1 pid svyyear using "$output/temp_indresp7" ,nogen keep(1 3)

merge 1:1 pid svyyear using "$output/temp_indresp99" ,nogen keep(1 3)

merge m:m hid svyyear using "$output/temp_hhrespallwav",nogen keep(1 3)

merge m:m hid svyyear using "$output/temp_hhresp2",nogen keep(1 3)

****************************************************************************************************************
***clean up

lab var svyyear "Survey year"

numlabel, add
compress
aorder

order pid hid svyyear
	
mvdecode _all, mv(-1 -2 -3 -4 -7 -9=.a \ -8=.b)

save "$output/temp_bhps",replace

**last line
