****************************************************************************************************************
****************************************************************************************************************
***Author: Sergi Vidal [svidal@ced.uab.es]; Philipp M. Lersch  
***Project: Vidal, Sergi and Philipp M. Lersch. 2019. “Changes in gender role attitudes following couples' residential relocations.” Demographic Research 40:1111–1152.
***Data set: British Household Panel Survey Waves 1-18 (UK Data Archive Study Number 5151); British Household Panel Survey, Waves 1-18, 1991-2009: Conditional Access, Local Authority Districts (UK Data Archive Study Number 6027)  
****************************************************************************************************************
****************************************************************************************************************

******************************************************
**S E C O N D A R Y (primary: MASTER.do)**
******************************************************


****************************************************************************************************************
****************************************************************************************************************
********Multivariate analysis (selection models)
****************************************************************************************************************
****************************************************************************************************************

use "$output/prepared",clear

keep if sample==1 

bysort pid (svyyear): gen time=_n

tab svyyear, gen(year)

xtset pid time

****************************************************************************************************************
***before/after comparison

qui: xtreg z_ideologya move_before timesincelastmove c.age b1993.svyyear married b0.children hhinclog empl jobhours p_empl p_jobhours b1.casmin2 househours homeowner hsroom urban if woman==0,fe vce(cluster pid)
gen analyticalsample= e(sample)
drop if analyticalsample==0 & woman==0
drop analyticalsample
qui: xtreg z_ideologya move_before timesincelastmove c.age b1993.svyyear married b0.children hhinclog empl jobhours p_empl p_jobhours b1.casmin2 househours homeowner hsroom urban if woman==1,fe vce(cluster pid)
gen analyticalsample= e(sample)
drop if analyticalsample==0 & woman==1
drop analyticalsample


*1. imputed cases - all observation 

set matsize 5000
preserve
drop if woman==1 
qui: xtdpdml ideologya move_repeated age, predet(move_before)  vce(cluster pid) fiml store(model1)
qui: xtdpdml ideologya move_repeated age , predet(moveshort_before movelong_before) vce(cluster pid) fiml store(model_dist1)
qui: xtdpdml ideologya movework_before movefam_before movedwel_before moveother_before age , predet(movework_before movefam_before movedwel_before moveother_before) vce(cluster pid) fiml store(model_mot1)
qui: xtdpdml ideologya move_repeated age , predet(moveforbothjob_before moveforhisjob_before moveforherjob_before movefornonejob_before) vce(cluster pid) fiml store(model_wmot1)
restore
preserve
drop if woman==0 
qui: xtdpdml ideologya move_repeated age, predet(move_before)  vce(cluster pid) fiml store(wodel1)
qui: xtdpdml ideologya move_repeated age , predet(moveshort_before movelong_before) vce(cluster pid) fiml store(wodel_dist1)
qui: xtdpdml ideologya movework_before movefam_before movedwel_before moveother_before age , predet(movework_before movefam_before movedwel_before moveother_before) vce(cluster pid) fiml store(wodel_mot1)
qui: xtdpdml ideologya move_repeated age , predet(moveforbothjob_before moveforhisjob_before moveforherjob_before movefornonejob_before) vce(cluster pid) fiml store(wodel_wmot1)
restore

forvalues w=0/1{
				di _c "."
				qui: xtreg ideologya move_before move_repeated age if woman==`w',fe vce(cluster pid)
				estimates store model1xt`w'
				qui: xtreg ideologya moveshort_before movelong_before move_repeated age if woman==`w',fe vce(cluster pid)
				estimates store model2xt`w'
				qui: xtreg ideologya movework_before movefam_before movedwel_before moveother_before move_repeated age if woman==`w',fe vce(cluster pid)
				estimates store model3xt`w'
				qui: xtreg ideologya moveforbothjob_before moveforhisjob_before moveforherjob_before movefornonejob_before move_repeated age if woman==`w',fe vce(cluster pid)
				estimates store model4xt`w'
			}
			
esttab model1xt0 model1_h model2xt0 model_dist1_h model3xt0 model_mot1_h model4xt0  using "$table/move_before_selection_model1a'.rtf",replace ///
	title("Table X: Linear dynamic fixed-effects models of gender ideology (Men)") ///
	cells("b(star fmt(2) label(B))" "se(par fmt(2) label((SE)))") nodep nonumb legend ///
	stats(ll N N_g,label("LL" "N Observations" "N Individuals") fmt(2 0 0)) ///
	 starlevels(* .1 ** .05 *** .01)	varwidth(25) modelwidth(6) ///
	 note("Data: BHPS (1991-2007, unweighted). Note: Outcome variable is egalitarian gender ideology, cluster robust standard errors in parentheses.")	

esttab model1xt1 wodel1_h model2xt1 wodel_dist1_h model3xt1 model_wot1_h model4xt1 model_wmot1 using "$table/move_before_selection_model1a'.rtf",append ///
	title("Table X: Linear dynamic fixed-effects models of gender ideology (Women)") ///
	cells("b(star fmt(2) label(B))" "se(par fmt(2) label((SE)))") nodep nonumb legend ///
	stats(ll N N_g,label("LL" "N Observations" "N Individuals") fmt(2 0 0)) ///
	 starlevels(* .1 ** .05 *** .01)	varwidth(25) modelwidth(6) ///
	 note("Data: BHPS (1991-2007, unweighted). Note: Outcome variable is egalitarian gender ideology, cluster robust standard errors in parentheses.")	

*2. only respondents with uninterrupted participation

set matsize 5000
preserve
drop if woman==1 
qui: xtdpdml ideologya move_repeated age svyyear, predet(move_before)  vce(cluster pid)  store(model1)
qui: xtdpdml ideologya move_repeated age svyyear, predet(moveshort_before movelong_before) vce(cluster pid)  store(model_dist1)
qui: xtdpdml ideologya move_repeated age svyyear, predet(movework_before movefam_before movedwel_before moveother_before) vce(cluster pid)  store(model_mot1)
qui: xtdpdml ideologya move_repeated age svyyear, predet(moveforbothjob_before moveforhisjob_before movefornonejob_before) vce(cluster pid)  store(model_wmot1) /*had to remove movefor her job*/
restore
preserve
drop if woman==0 
qui: xtdpdml ideologya move_repeated age svyyear, predet(moveforbothjob_before moveforhisjob_before movefornonejob_before) vce(cluster pid)  store(wodel_wmot1) /*had to remove movefor her job*/
restore
preserve
bysort pid (svyyear): gen count=_n
bysort pid (svyyear): egen max=max(count)
drop if max!=8
forvalues w=0/1{
				di _c "."
				qui: xtreg ideologya move_before move_repeated age svyyear if woman==`w',fe vce(cluster pid)
				estimates store model1xt`w'
				qui: xtreg ideologya moveshort_before movelong_before move_repeated age svyyear if woman==`w',fe vce(cluster pid)
				estimates store model2xt`w'
				qui: xtreg ideologya movework_before movefam_before movedwel_before moveother_before move_repeated age svyyear if woman==`w',fe vce(cluster pid)
				estimates store model3xt`w'
				qui: xtreg ideologya moveforbothjob_before moveforhisjob_before moveforherjob_before movefornonejob_before move_repeated age svyyear if woman==`w',fe vce(cluster pid)
				estimates store model4xt`w'
			}
restore			
esttab model1xt0 model1_h model2xt0 model_dist1_h model3xt0 model_mot1_h model4xt0 model_wmot1_h  using "$table/move_before_selection_model1c'.rtf",replace ///
	title("Table X: Linear dynamic fixed-effects models of gender ideology (Men)") ///
	cells("b(star fmt(2) label(B))" "se(par fmt(2) label((SE)))") nodep nonumb legend ///
	stats(ll N N_g,label("LL" "N Observations" "N Individuals") fmt(2 0 0)) ///
	 starlevels(* .1 ** .05 *** .01)	varwidth(25) modelwidth(6) ///
	 note("Data: BHPS (1991-2007, unweighted). Note: Outcome variable is egalitarian gender ideology, cluster robust standard errors in parentheses.")	

esttab model1xt1 wodel1_h model2xt1 wodel_dist1_h model3xt1 wodel_mot1_h model4xt1 wodel_wmot1_h using "$table/move_before_selection_model1c'.rtf",append ///
	title("Table X: Linear dynamic fixed-effects models of gender ideology (Women)") ///
	cells("b(star fmt(2) label(B))" "se(par fmt(2) label((SE)))") nodep nonumb legend ///
	stats(ll N N_g,label("LL" "N Observations" "N Individuals") fmt(2 0 0)) ///
	 starlevels(* .1 ** .05 *** .01)	varwidth(25) modelwidth(6) ///
	 note("Data: BHPS (1991-2007, unweighted). Note: Outcome variable is egalitarian gender ideology, cluster robust standard errors in parentheses.")
	 
*3. regular FE with lagged DV

bysort pid (svyyear): gen lagideologya=ideologya[_n-1]
forvalues w=0/1{
				di _c "."
				qui: xtreg ideologya lagideologya move_before move_repeated c.age b1993.svyyear if woman==`w',fe vce(cluster pid)
				estimates store model1xt`w'_lag
				gen sample`w'1= e(sample)
				qui: xtreg ideologya lagideologya moveshort_before movelong_before move_repeated c.age b1993.svyyear if woman==`w',fe vce(cluster pid)
				estimates store model2xt`w'_lag
				gen sample`w'2= e(sample)
				qui: xtreg ideologya lagideologya movework_before movefam_before movedwel_before moveother_before move_repeated c.age b1993.svyyear if woman==`w',fe vce(cluster pid)
				estimates store model3xt`w'_lag
				gen sample`w'3= e(sample)
				qui: xtreg ideologya lagideologya moveforbothjob_before moveforhisjob_before moveforherjob_before movefornonejob_before move_repeated c.age b1993.svyyear if woman==`w',fe vce(cluster pid)
				estimates store model4xt`w'_lag
				gen sample`w'4= e(sample)
			}	
forvalues w=0/1{
				di _c "."
				qui: xtreg ideologya  move_before move_repeated c.age b1993.svyyear if woman==`w' & sample`w'1==1,fe vce(cluster pid)
				estimates store model1xt`w'
				qui: xtreg ideologya  moveshort_before movelong_before move_repeated c.age b1993.svyyear if woman==`w' & sample`w'2==1,fe vce(cluster pid)
				estimates store model2xt`w'
				qui: xtreg ideologya  movework_before movefam_before movedwel_before moveother_before move_repeated c.age b1993.svyyear if woman==`w' & sample`w'3==1,fe vce(cluster pid)
				estimates store model3xt`w'
				qui: xtreg ideologya  moveforbothjob_before moveforhisjob_before moveforherjob_before movefornonejob_before move_repeated c.age b1993.svyyear if woman==`w' & sample`w'4==1,fe vce(cluster pid)
				estimates store model4xt`w'
			}	
esttab model1xt0 model1xt0_lag model2xt0 model2xt0_lag model3xt0 model3xt0_lag model4xt0 model4xt0_lag  using "$table/move_before_selection_model1c'.rtf",replace ///
	title("Table X: Linear dynamic fixed-effects models of gender ideology (Men)") ///
	cells("b(star fmt(2) label(B))" "se(par fmt(2) label((SE)))") nodep nonumb legend ///
	stats(ll N N_g,label("LL" "N Observations" "N Individuals") fmt(2 0 0)) ///
	 starlevels(* .1 ** .05 *** .01)	varwidth(25) modelwidth(6) ///
	 note("Data: BHPS (1991-2007, unweighted). Note: Outcome variable is egalitarian gender ideology, cluster robust standard errors in parentheses.")	

esttab model1xt1 model1xt1_lag model2xt1 model2xt1_lag model3xt1 model3xt1_lag model4xt1 model4xt1_lag using "$table/move_before_selection_model1c'.rtf",append ///
	title("Table X: Linear dynamic fixed-effects models of gender ideology (Women)") ///
	cells("b(star fmt(2) label(B))" "se(par fmt(2) label((SE)))") nodep nonumb legend ///
	stats(ll N N_g,label("LL" "N Observations" "N Individuals") fmt(2 0 0)) ///
	 starlevels(* .1 ** .05 *** .01)	varwidth(25) modelwidth(6) ///
	 note("Data: BHPS (1991-2007, unweighted). Note: Outcome variable is egalitarian gender ideology, cluster robust standard errors in parentheses.")

	 
*3. regular FE with lagged relocation var

bysort pid (svyyear): gen lag_move_before=move_before[_n-1]
bysort pid (svyyear): gen lag_moveshort_before=moveshort_before[_n-1]
bysort pid (svyyear): gen lag_movelong_before=movelong_before[_n-1]
bysort pid (svyyear): gen lag_movework_before=movework_before[_n-1]
bysort pid (svyyear): gen lag_movefam_before=movefam_before[_n-1]
bysort pid (svyyear): gen lag_movedwel_before=movedwel_before[_n-1]
bysort pid (svyyear): gen lag_moveother_before=moveother_before[_n-1]
bysort pid (svyyear): gen lag_moveforbothjob_before=moveforbothjob_before[_n-1]
bysort pid (svyyear): gen lag_moveforhisjob_before=moveforhisjob_before[_n-1]
bysort pid (svyyear): gen lag_moveforherjob_before=moveforherjob_before[_n-1]
bysort pid (svyyear): gen lag_movefornonejob_before=movefornonejob_before[_n-1]

forvalues w=0/1{
				di _c "."
				qui: xtreg z_ideologya move_before lag_move_before move_repeated timesincelastmove i.age_cat2 b1993.svyyear if woman==`w',fe vce(cluster pid)
				estimates store model1xt`w'_lag
				gen sample`w'1= e(sample)
				qui: xtreg z_ideologya  moveshort_before movelong_before lag_moveshort_before lag_movelong_before move_repeated timesincelastmove i.age_cat2 b1993.svyyear if woman==`w',fe vce(cluster pid)
				estimates store model2xt`w'_lag
				gen sample`w'2= e(sample)
				qui: xtreg z_ideologya movework_before movefam_before movedwel_before moveother_before lag_movework_before lag_movefam_before lag_movedwel_before lag_moveother_before move_repeated timesincelastmove i.age_cat2 b1993.svyyear if woman==`w',fe vce(cluster pid)
				estimates store model3xt`w'_lag
				gen sample`w'3= e(sample)
				qui: xtreg z_ideologya moveforbothjob_before moveforhisjob_before moveforherjob_before movefornonejob_before lag_moveforbothjob_before lag_moveforhisjob_before lag_moveforherjob_before lag_movefornonejob_before move_repeated timesincelastmove i.age_cat2 b1993.svyyear if woman==`w',fe vce(cluster pid)
				estimates store model4xt`w'_lag
				gen sample`w'4= e(sample)
			}	
forvalues w=0/1{
				di _c "."
				qui: xtreg z_ideologya  move_before move_repeated timesincelastmove i.age_cat2 b1993.svyyear if woman==`w' & sample`w'1==1,fe vce(cluster pid)
				estimates store model1xt`w'
				qui: xtreg z_ideologya  moveshort_before movelong_before move_repeated timesincelastmove i.age_cat2 b1993.svyyear if woman==`w' & sample`w'2==1,fe vce(cluster pid)
				estimates store model2xt`w'
				qui: xtreg z_ideologya  movework_before movefam_before movedwel_before moveother_before move_repeated timesincelastmove i.age_cat2 b1993.svyyear if woman==`w' & sample`w'3==1,fe vce(cluster pid)
				estimates store model3xt`w'
				qui: xtreg z_ideologya  moveforbothjob_before moveforhisjob_before moveforherjob_before movefornonejob_before move_repeated timesincelastmove i.age_cat2 b1993.svyyear if woman==`w' & sample`w'4==1,fe vce(cluster pid)
				estimates store model4xt`w'
			}	
esttab model1xt0 model1xt0_lag model2xt0 model2xt0_lag model3xt0 model3xt0_lag model4xt0 model4xt0_lag  using "$table/move_before_selection_model1c'.rtf",replace ///
	title("Table X: Linear dynamic fixed-effects models of gender ideology (Men)") ///
	cells("b(star fmt(2) label(B))" "se(par fmt(2) label((SE)))") nodep nonumb legend ///
	stats(ll N N_g,label("LL" "N Observations" "N Individuals") fmt(2 0 0)) ///
	 starlevels(* .1 ** .05 *** .01)	varwidth(25) modelwidth(6) ///
	 note("Data: BHPS (1991-2007, unweighted). Note: Outcome variable is egalitarian gender ideology, cluster robust standard errors in parentheses.")	

esttab model1xt1 model1xt1_lag model2xt1 model2xt1_lag model3xt1 model3xt1_lag model4xt1 model4xt1_lag using "$table/move_before_selection_model1c'.rtf",append ///
	title("Table X: Linear dynamic fixed-effects models of gender ideology (Women)") ///
	cells("b(star fmt(2) label(B))" "se(par fmt(2) label((SE)))") nodep nonumb legend ///
	stats(ll N N_g,label("LL" "N Observations" "N Individuals") fmt(2 0 0)) ///
	 starlevels(* .1 ** .05 *** .01)	varwidth(25) modelwidth(6) ///
	 note("Data: BHPS (1991-2007, unweighted). Note: Outcome variable is egalitarian gender ideology, cluster robust standard errors in parentheses.")
	 
	 
	 
***last line	 

