****************************************************************************************************************
****************************************************************************************************************
***Author: Sergi Vidal [svidal@ced.uab.es]; Philipp M. Lersch  
***Project: Vidal, Sergi and Philipp M. Lersch. 2019. “Changes in gender role attitudes following couples' residential relocations.” Demographic Research 40:1111–1152.
***Data set: British Household Panel Survey Waves 1-18 (UK Data Archive Study Number 5151); British Household Panel Survey, Waves 1-18, 1991-2009: Conditional Access, Local Authority Districts (UK Data Archive Study Number 6027)  
****************************************************************************************************************
****************************************************************************************************************

******************************************************
**S E C O N D A R Y (primary: MASTER.do)**
******************************************************


****************************************************************************************************************
****************************************************************************************************************
********Multivariate analysis (sensitivity analysis: GRA based on 6 items)
****************************************************************************************************************
****************************************************************************************************************

use "$output/prepared",clear

keep if sample==1

xtset pid svyyear

****************************************************************************************************************
***before/after comparison

qui: xtreg ideologyb move_before move_repeated c.age b1993.svyyear married b0.children hhinclog empl jobhours p_empl p_jobhours b1.casmin2 homeowner hsroom urban if woman==0,fe vce(cluster pid)
gen analyticalsample= e(sample)
drop if analyticalsample==0 & woman==0
drop analyticalsample
qui: xtreg ideologyb move_before move_repeated c.age b1993.svyyear married b0.children hhinclog empl jobhours p_empl p_jobhours b1.casmin2 homeowner hsroom urban if woman==1,fe vce(cluster pid)
gen analyticalsample= e(sample)
drop if analyticalsample==0 & woman==1
drop analyticalsample

local model1 "move_repeated c.age b1993.svyyear"
local model2 "move_repeated c.age b1993.svyyear married b0.children hhinclog empl jobhours p_empl p_jobhours b1.casmin2" 
local model3 "move_repeated c.age b1993.svyyear married b0.children  hhinclog empl jobhours p_empl p_jobhours b1.casmin2 homeowner hsroom urban"
local title1 "Women"
local title0 "Men"

forvalues w=0/1{
		forvalues m=1/3{
				di _c "."
				qui: xtreg ideologyb move_before `model`m'' if woman==`w',fe vce(cluster pid)
				estimates store est_move_before`m'_w`w'_fe
				qui: xtreg ideologyb moveshort_before movelong_before `model`m'' if woman==`w',fe vce(cluster pid)
				estimates store est_movedist_before`m'_w`w'_fe
				qui: xtreg ideologyb movework_before movefam_before movedwel_before moveother_before `model`m'' if woman==`w',fe vce(cluster pid)
				estimates store est_movreas_before`m'_w`w'_fe
				qui: xtreg ideologyb moveforbothjob_before moveforhisjob_before moveforherjob_before movefornonejob_before `model`m'' if woman==`w',fe vce(cluster pid)
				estimates store est_movcreas_before`m'_w`w'_fe
			}
esttab est_move_before?_w`w'_fe using "$table/GRA_6itmes_`title`w''.rtf",replace ///
	title("Table X: Linear fixed-effects models of gender ideology (`title`w'')") ///
	cells("b(star fmt(2) label(B))" "se(par fmt(2) label((SE)))") nodep nonumb legend ///
	mgroups("All moves",pattern(1 0 0)) ///
	ml("Model 1" "Model 2" "Model 3") ///
	stats(ll N N_g,label("LL" "N Observations" "N Individuals") fmt(2 0 0)) ///
	keep(move_before move_repeated) ///
	 starlevels(* .1 ** .05 *** .01)	varwidth(25) modelwidth(6) ///
	 note("Data: BHPS (1991-2007, unweighted). Note: Outcome variable is egalitarian gender ideology, cluster robust standard errors in parentheses.")	
		
esttab est_movedist_before?_w`w'_fe using "$table/GRA_6itmes_`title`w''.rtf",append ///
	title("Table X: Linear fixed-effects models of gender ideology (`title`w'')") ///
	cells("b(star fmt(2) label(B))" "se(par fmt(2) label((SE)))") nodep nonumb legend ///
	mgroups("Short-distance moves" "Long-distance moves",pattern(1 0 0)) ///
	ml("Model 1" "Model 2" "Model 3" ) ///
	stats(ll N N_g,label("LL" "N Observations" "N Individuals") fmt(2 0 0)) ///
	keep(moveshort_before movelong_before) ///
	 starlevels(* .1 ** .05 *** .01)	varwidth(25) modelwidth(6) ///
	 note("Data: BHPS (1991-2007, unweighted). Note: Outcome variable is egalitarian gender ideology, cluster robust standard errors in parentheses.")	

esttab est_movreas_before?_w`w'_fe  using "$table/GRA_6itmes_`title`w''.rtf",append ///
	title("Table X: Linear fixed-effects models of gender ideology (`title`w'')") ///
	cells("b(star fmt(2) label(B))" "se(par fmt(2) label((SE)))") nodep nonumb legend ///
	mgroups("Moved for job" "Moved for family" "Moved for housing / area" "Moved for other",pattern(1 0 0)) ///
	ml("Model 1" "Model 2" "Model 3") ///
	stats(ll N N_g,label("LL" "N Observations" "N Individuals") fmt(2 0 0)) ///
	keep(movework_before movefam_before movedwel_before moveother_before) ///
	 starlevels(* .1 ** .05 *** .01)	varwidth(25) modelwidth(6) ///
	 note("Data: BHPS (1991-2007, unweighted). Note: Outcome variable is egalitarian gender ideology, cluster robust standard errors in parentheses.")		 
	 
esttab est_movcreas_before?_w`w'_fe using "$table/GRA_6itmes_`title`w''.rtf",append ///
	title("Table X: Linear fixed-effects models of gender ideology (`title`w'')") ///
	cells("b(star fmt(2) label(B))" "se(par fmt(2) label((SE)))") nodep nonumb legend ///
	ml("Model 1" "Model 2" "Model 3") ///
	stats(ll N N_g,label("LL" "N Observations" "N Individuals") fmt(2 0 0)) ///
	keep(moveforbothjob_before moveforhisjob_before moveforherjob_before movefornonejob_before) ///
	 starlevels(* .1 ** .05 *** .01)	varwidth(25) modelwidth(6) ///
	 note("Data: BHPS (1991-2007, unweighted). Note: Outcome variable is egalitarian gender ideology, cluster robust standard errors in parentheses.")				
	 	}		
	
**last line

